@@ -8,6 +8,8 @@
 #include <QCommandLineParser>
 #include <QGuiApplication>
 
+#include "../src/config-kalendar.h"
+
 int main(int argc, char **argv)
 {
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
@@ -20,7 +22,7 @@ int main(int argc, char **argv)
         QStringLiteral("kalendarac"),
         // A displayable program name string.
         i18nc("@title", "Kalendar Reminders"),
-        QStringLiteral(),
+        QStringLiteral(KALENDAR_VERSION_STRING),
         // Short description of what the app does.
         i18n("Kalendar Reminder Daemon"),
         // The license this code is released under.
