@@ -8,13 +8,8 @@
 #include <QTimer>
 
 #include <akonadi_version.h>
-#if AKONADI_VERSION >= QT_VERSION_CHECK(5, 18, 41)
 #include <Akonadi/EntityTreeModel>
 #include <Akonadi/ServerManager>
-#else
-#include <AkonadiCore/EntityTreeModel>
-#include <AkonadiCore/ServerManager>
-#endif
 #include <Akonadi/Calendar/ETMCalendar>
 
 class AlarmNotification;
@@ -31,17 +26,20 @@ public:
     void dismiss(AlarmNotification *notification);
     /** Suspends the display of the alarm \p notification. */
     void suspend(AlarmNotification *notification);
+    /** Show incidence in the calendar application. */
+    void showIncidence(const QString &uid, const QDateTime &occurrence, const QString &xdgActivationToken);
 
 private:
     void deferredInit();
     void restoreSuspendedFromConfig();
     void storeNotification(AlarmNotification *notification);
     void removeNotification(AlarmNotification *notification);
-    void addNotification(const QString &uid, const QString &text, const QDateTime &remindTime);
+    void addNotification(const QString &uid, const QString &text, const QDateTime &occurrence, const QDateTime &remindTime);
     void checkAlarms();
     void setupAkonadi();
     Q_REQUIRED_RESULT bool collectionsAvailable() const;
     void saveLastCheckTime();
+    QDateTime occurrenceForAlarm(const KCalendarCore::Incidence::Ptr &incidence, const KCalendarCore::Alarm::Ptr &alarm, const QDateTime &from) const;
 
     Akonadi::ETMCalendar::Ptr mCalendar;
     Akonadi::EntityTreeModel *mETM = nullptr;
