@@ -2,19 +2,13 @@
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include "agentconfiguration.h"
-#if AKONADI_VERSION >= QT_VERSION_CHECK(5, 18, 41)
+
 #include <Akonadi/AgentConfigurationDialog>
 #include <Akonadi/AgentInstanceCreateJob>
 #include <Akonadi/AgentInstanceModel>
 #include <Akonadi/AgentManager>
 #include <Akonadi/AgentTypeModel>
-#else
-#include <AgentConfigurationDialog>
-#include <AkonadiCore/AgentInstanceCreateJob>
-#include <AkonadiCore/AgentInstanceModel>
-#include <AkonadiCore/AgentManager>
-#include <AkonadiCore/AgentTypeModel>
-#endif
+
 #include <KWindowSystem>
 #include <QPointer>
 
@@ -75,6 +69,17 @@ void AgentConfiguration::edit(int index)
     Q_ASSERT(m_runningAgents != nullptr);
 
     auto instance = m_runningAgents->data(m_runningAgents->index(index, 0), AgentInstanceModel::InstanceRole).value<AgentInstance>();
+    setupEdit(instance);
+}
+
+void AgentConfiguration::editIdentifier(QString resourceIdentifier)
+{
+    auto instance = Akonadi::AgentManager::self()->instance(resourceIdentifier);
+    setupEdit(instance);
+}
+
+void AgentConfiguration::setupEdit(Akonadi::AgentInstance instance)
+{
     if (instance.isValid()) {
         KWindowSystem::allowExternalProcessWindowActivation();
         QPointer<AgentConfigurationDialog> dlg(new AgentConfigurationDialog(instance, nullptr));
@@ -88,6 +93,17 @@ void AgentConfiguration::restart(int index)
     Q_ASSERT(m_runningAgents != nullptr);
 
     auto instance = m_runningAgents->data(m_runningAgents->index(index, 0), AgentInstanceModel::InstanceRole).value<AgentInstance>();
+    setupRestart(instance);
+}
+
+void AgentConfiguration::restartIdentifier(QString resourceIdentifier)
+{
+    auto instance = Akonadi::AgentManager::self()->instance(resourceIdentifier);
+    setupRestart(instance);
+}
+
+void AgentConfiguration::setupRestart(Akonadi::AgentInstance instance)
+{
     if (instance.isValid()) {
         instance.restart();
     }
@@ -98,6 +114,17 @@ void AgentConfiguration::remove(int index)
     Q_ASSERT(m_runningAgents != nullptr);
 
     auto instance = m_runningAgents->data(m_runningAgents->index(index, 0), AgentInstanceModel::InstanceRole).value<AgentInstance>();
+    setupRemove(instance);
+}
+
+void AgentConfiguration::removeIdentifier(QString resourceIdentifier)
+{
+    auto instance = Akonadi::AgentManager::self()->instance(resourceIdentifier);
+    setupRemove(instance);
+}
+
+void AgentConfiguration::setupRemove(Akonadi::AgentInstance instance)
+{
     if (instance.isValid()) {
         Akonadi::AgentManager::self()->removeInstance(instance);
     }
