@@ -11,7 +11,6 @@
 #include "calendarmanager.h"
 
 // Akonadi
-#if AKONADI_VERSION >= QT_VERSION_CHECK(5, 18, 41)
 #include <Akonadi/AgentInstanceModel>
 #include <Akonadi/AgentManager>
 #include <Akonadi/AttributeFactory>
@@ -27,24 +26,6 @@
 #include <Akonadi/ItemModifyJob>
 #include <Akonadi/ItemMoveJob>
 #include <Akonadi/Monitor>
-#else
-#include <AkonadiCore/AgentInstanceModel>
-#include <AkonadiCore/AgentManager>
-#include <AkonadiCore/AttributeFactory>
-#include <AkonadiCore/CollectionColorAttribute>
-#include <AkonadiCore/CollectionDeleteJob>
-#include <AkonadiCore/CollectionIdentificationAttribute>
-#include <AkonadiCore/CollectionModifyJob>
-#include <AkonadiCore/CollectionUtils>
-#include <AkonadiCore/EntityDisplayAttribute>
-#include <AkonadiCore/ItemModifyJob>
-#include <AkonadiCore/ItemMoveJob>
-#include <AkonadiWidgets/CollectionPropertiesDialog>
-#include <CollectionFilterProxyModel>
-#include <EntityTreeModel>
-#include <Monitor>
-#include <control.h>
-#endif
 #include "kalendar_debug.h"
 #include <Akonadi/Calendar/History>
 #include <EventViews/Prefs>
@@ -467,6 +448,10 @@ CalendarManager::CalendarManager(QObject *parent)
         }
     };
     connect(m_flatCollectionTreeModel, &QSortFilterProxyModel::rowsInserted, this, refreshColors);
+
+    KConfigGroup rColorsConfig(config, "Resources Colors");
+    m_colorWatcher = KConfigWatcher::create(config);
+    QObject::connect(m_colorWatcher.data(), &KConfigWatcher::configChanged, this, &CalendarManager::collectionColorsChanged);
 }
 
 CalendarManager::~CalendarManager()
@@ -552,9 +537,9 @@ KCheckableProxyModel *CalendarManager::collectionSelectionProxyModel() const
     return m_selectionProxyModel;
 }
 
-Akonadi::ETMCalendar *CalendarManager::calendar() const
+Akonadi::ETMCalendar::Ptr CalendarManager::calendar() const
 {
-    return m_calendar.get();
+    return m_calendar;
 }
 
 Akonadi::IncidenceChanger *CalendarManager::incidenceChanger() const
@@ -904,10 +889,12 @@ QVariantMap CalendarManager::getCollectionDetails(QVariant collectionId)
     collectionDetails[QLatin1String("color")] = m_baseModel->colorCache[QString::number(collection.id())];
     collectionDetails[QLatin1String("count")] = collection.statistics().count();
     collectionDetails[QLatin1String("isResource")] = Akonadi::CollectionUtils::isResource(collection);
+    collectionDetails[QLatin1String("resource")] = collection.resource();
     collectionDetails[QLatin1String("readOnly")] = collection.rights().testFlag(Collection::ReadOnly);
     collectionDetails[QLatin1String("canChange")] = collection.rights().testFlag(Collection::CanChangeCollection);
     collectionDetails[QLatin1String("canCreate")] = collection.rights().testFlag(Collection::CanCreateCollection);
-    collectionDetails[QLatin1String("canDelete")] = collection.rights().testFlag(Collection::CanDeleteCollection);
+    collectionDetails[QLatin1String("canDelete")] =
+        collection.rights().testFlag(Collection::CanDeleteCollection) && !Akonadi::CollectionUtils::isResource(collection);
     collectionDetails[QLatin1String("isFiltered")] = isFiltered;
     collectionDetails[QLatin1String("allCalendarsRow")] = allCalendarsRow;
 
@@ -962,7 +949,7 @@ void CalendarManager::deleteCollection(qint64 collectionId)
     if (!isTopLevel) {
         // deletes contents
         auto job = new Akonadi::CollectionDeleteJob(collection, this);
-        connect(job, &Akonadi::CollectionDeleteJob::result, this, [this](KJob *job) {
+        connect(job, &Akonadi::CollectionDeleteJob::result, this, [](KJob *job) {
             if (job->error()) {
                 qCWarning(KALENDAR_LOG) << "Error occurred deleting collection: " << job->errorString();
             }
