@@ -6,23 +6,17 @@
 
 #include <QObject>
 #include <akonadi_version.h>
-#if AKONADI_VERSION >= QT_VERSION_CHECK(5, 18, 41)
 #include <Akonadi/AgentFilterProxyModel>
 #include <Akonadi/CollectionFilterProxyModel>
 #include <Akonadi/ETMViewStateSaver>
 #include <Akonadi/EntityRightsFilterModel>
-#else
-#include <AkonadiCore/AgentFilterProxyModel>
-#include <AkonadiCore/CollectionFilterProxyModel>
-#include <AkonadiCore/EntityRightsFilterModel>
-#include <ETMViewStateSaver>
-#endif
 #include <Akonadi/Calendar/IncidenceChanger>
 #include <CalendarSupport/KCalPrefs>
 #include <CalendarSupport/Utils>
+#include <KConfigWatcher>
 #include <KDescendantsProxyModel>
 #include <incidencewrapper.h>
-#include <todosortfilterproxymodel.h>
+#include <models/todosortfilterproxymodel.h>
 
 namespace Akonadi
 {
@@ -46,7 +40,7 @@ class CalendarManager : public QObject
     Q_PROPERTY(Akonadi::CollectionFilterProxyModel *selectableCalendars READ selectableCalendars CONSTANT)
     Q_PROPERTY(Akonadi::CollectionFilterProxyModel *selectableEventCalendars READ selectableEventCalendars CONSTANT)
     Q_PROPERTY(Akonadi::CollectionFilterProxyModel *selectableTodoCalendars READ selectableTodoCalendars CONSTANT)
-    Q_PROPERTY(Akonadi::ETMCalendar *calendar READ calendar CONSTANT)
+    Q_PROPERTY(Akonadi::ETMCalendar::Ptr calendar READ calendar CONSTANT)
     Q_PROPERTY(Akonadi::IncidenceChanger *incidenceChanger READ incidenceChanger CONSTANT)
     Q_PROPERTY(QVariantMap undoRedoData READ undoRedoData NOTIFY undoRedoDataChanged)
 
@@ -65,7 +59,7 @@ public:
     void refreshEnabledTodoCollections();
 
     Q_INVOKABLE void save();
-    Akonadi::ETMCalendar *calendar() const;
+    Akonadi::ETMCalendar::Ptr calendar() const;
     Akonadi::IncidenceChanger *incidenceChanger() const;
     Akonadi::CollectionFilterProxyModel *allCalendars();
     Akonadi::CollectionFilterProxyModel *selectableCalendars() const;
@@ -109,6 +103,7 @@ Q_SIGNALS:
     void incidenceChanged();
     void enabledTodoCollectionsChanged();
     void updateIncidenceDatesCompleted();
+    void collectionColorsChanged();
 
 private:
     Akonadi::ETMCalendar::Ptr m_calendar = nullptr;
@@ -129,4 +124,7 @@ private:
     Akonadi::CollectionFilterProxyModel *m_todoViewCollectionModel = nullptr;
     Akonadi::CollectionFilterProxyModel *m_viewCollectionModel = nullptr;
     QVector<qint64> m_enabledTodoCollections;
+    KConfigWatcher::Ptr m_colorWatcher;
 };
+
+Q_DECLARE_METATYPE(Akonadi::ETMCalendar::Ptr);
