@@ -8,11 +8,7 @@
 #include <QObject>
 #include <QSortFilterProxyModel>
 #include <akonadi_version.h>
-#if AKONADI_VERSION >= QT_VERSION_CHECK(5, 18, 41)
 #include <Akonadi/EntityMimeTypeFilterModel>
-#else
-#include <AkonadiCore/EntityMimeTypeFilterModel>
-#endif
 
 class QSortFilterProxyModel;
 
