@@ -354,6 +354,21 @@ QString IncidenceWrapper::incidenceEndTimeDisplay() const
     return QLocale::system().toString(incidenceEnd().time(), QLocale::NarrowFormat);
 }
 
+void IncidenceWrapper::setIncidenceTimeToNearestQuarterHour(bool setStartTime, bool setEndTime)
+{
+    const int now = QDateTime::currentSecsSinceEpoch();
+    const int quarterHourInSecs = 15 * 60;
+    const int secsToSet = now + (quarterHourInSecs - now % quarterHourInSecs);
+    QDateTime startTime = QDateTime::currentDateTime();
+    startTime.setSecsSinceEpoch(secsToSet);
+    if (setStartTime) {
+        setIncidenceStart(startTime, true);
+    }
+    if (setEndTime) {
+        setIncidenceEnd(startTime.addSecs(3600), true);
+    }
+}
+
 QByteArray IncidenceWrapper::timeZone() const
 {
     return incidenceEnd().timeZone().id();
@@ -722,5 +737,6 @@ void IncidenceWrapper::itemChanged(const Akonadi::Item &item)
         setIncidencePtr(item.payload<KCalendarCore::Incidence::Ptr>());
     }
 }
-
+#ifndef UNITY_CMAKE_SUPPORT
 Q_DECLARE_METATYPE(KCalendarCore::Incidence::Ptr);
+#endif
