@@ -9,23 +9,15 @@
 #include <QByteArray>
 #include <QObject>
 #include <akonadi_version.h>
-#if AKONADI_VERSION >= QT_VERSION_CHECK(5, 18, 41)
 #include <Akonadi/CollectionIdentificationAttribute>
 #include <Akonadi/Item>
 #include <Akonadi/ItemFetchJob>
 #include <Akonadi/ItemFetchScope>
 #include <Akonadi/ItemMonitor>
-#else
-#include <AkonadiCore/CollectionIdentificationAttribute>
-#include <AkonadiCore/Item>
-#include <AkonadiCore/ItemFetchJob>
-#include <AkonadiCore/ItemFetchScope>
-#include <AkonadiCore/ItemMonitor>
-#endif
-#include "attachmentsmodel.h"
-#include "attendeesmodel.h"
-#include "recurrenceexceptionsmodel.h"
-#include "remindersmodel.h"
+#include "models/attachmentsmodel.h"
+#include "models/attendeesmodel.h"
+#include "models/recurrenceexceptionsmodel.h"
+#include "models/remindersmodel.h"
 
 /**
  * This class is a wrapper for a KCalendarCore::Incidence::Ptr object.
@@ -148,6 +140,7 @@ public:
     Q_INVOKABLE void setIncidenceEndTime(int hours, int minutes);
     QString incidenceEndDateDisplay() const;
     QString incidenceEndTimeDisplay() const;
+    Q_INVOKABLE void setIncidenceTimeToNearestQuarterHour(bool setStartTime = true, bool setEndTime = true);
     QByteArray timeZone() const;
     void setTimeZone(const QByteArray &timeZone);
     int startTimeZoneUTCOffsetMins();
