@@ -4,8 +4,8 @@
 // SPDX-License-Identifier: LGPL-3.0-or-later
 
 #pragma once
-#include "actionsmodel.h"
 #include "kalendarconfig.h"
+#include "models/actionsmodel.h"
 #include <Akonadi/Calendar/ETMCalendar>
 #include <Akonadi/Calendar/ICalImporter>
 #include <KActionCollection>
@@ -36,10 +36,13 @@ public:
     void setWindow(QWindow *window);
 
     QSortFilterProxyModel *actionsModel();
-    void setCalendar(Akonadi::ETMCalendar *calendar);
+    void setCalendar(Akonadi::ETMCalendar::Ptr calendar);
     Q_INVOKABLE void importCalendarFromUrl(const QUrl &url, bool merge, qint64 collectionId = -1);
     QString importErrorMessage();
 
+    // D-Bus interface
+    void showIncidenceByUid(const QString &uid, const QDateTime &occurrence, const QString &xdgActivationToken);
+
 public Q_SLOTS:
     void configureShortcuts();
 
@@ -80,6 +83,7 @@ Q_SIGNALS:
     void importIntoNewFinished(bool success);
     void importErrorMessageChanged();
     void refreshAllCalendars();
+    void openIncidence(const QVariantMap incidenceData, const QDateTime occurrence);
 
 private:
     KActionCollection mCollection;
@@ -91,6 +95,6 @@ private:
     KalCommandBarModel *m_actionModel = nullptr;
     QSortFilterProxyModel *m_proxyModel = nullptr;
     KalendarConfig *m_config = nullptr;
-    Akonadi::ETMCalendar *m_calendar;
+    Akonadi::ETMCalendar::Ptr m_calendar;
     QString m_importErrorMessage;
 };
