@@ -21,27 +21,23 @@
 #include <QQuickWindow>
 #include <QUrl>
 #include <akonadi_version.h>
-#if AKONADI_VERSION >= QT_VERSION_CHECK(5, 18, 41)
 #include <Akonadi/AgentFilterProxyModel>
-#else
-#include <AkonadiCore/AgentFilterProxyModel>
-#endif
 #include "about.h"
 #include "agentconfiguration.h"
 #include "calendarmanager.h"
 #include "config-kalendar.h"
 #include "contactsmanager.h"
-#include "hourlyincidencemodel.h"
-#include "incidenceoccurrencemodel.h"
 #include "incidencewrapper.h"
-#include "infinitecalendarviewmodel.h"
-#include "itemtagsmodel.h"
 #include "kalendarapplication.h"
 #include "kalendarconfig.h"
-#include "monthmodel.h"
-#include "multidayincidencemodel.h"
+#include "models/hourlyincidencemodel.h"
+#include "models/incidenceoccurrencemodel.h"
+#include "models/infinitecalendarviewmodel.h"
+#include "models/itemtagsmodel.h"
+#include "models/monthmodel.h"
+#include "models/multidayincidencemodel.h"
+#include "models/timezonelistmodel.h"
 #include "tagmanager.h"
-#include "timezonelistmodel.h"
 
 using namespace KCalendarCore;
 
@@ -83,7 +79,7 @@ int main(int argc, char *argv[])
         // Short description of what the app does.
         i18n("Calendar Application"),
         // The license this code is released under.
-        KAboutLicense::GPL,
+        KAboutLicense::GPL_V3,
         // Copyright Statement.
         i18n("(c) KDE Community 2021"));
     aboutData.addAuthor(i18nc("@info:credit", "Carl Schwan"),
@@ -144,7 +140,6 @@ int main(int argc, char *argv[])
     qmlRegisterType<AttendeesModel>("org.kde.kalendar", 1, 0, "AttendeesModel");
     qmlRegisterType<MultiDayIncidenceModel>("org.kde.kalendar", 1, 0, "MultiDayIncidenceModel");
     qmlRegisterType<IncidenceOccurrenceModel>("org.kde.kalendar", 1, 0, "IncidenceOccurrenceModel");
-    qmlRegisterType<ExtraTodoModel>("org.kde.kalendar", 1, 0, "ExtraTodoModel");
     qmlRegisterType<TodoSortFilterProxyModel>("org.kde.kalendar", 1, 0, "TodoSortFilterProxyModel");
     qmlRegisterType<ItemTagsModel>("org.kde.kalendar", 1, 0, "ItemTagsModel");
     qmlRegisterType<HourlyIncidenceModel>("org.kde.kalendar", 1, 0, "HourlyIncidenceModel");
@@ -152,6 +147,7 @@ int main(int argc, char *argv[])
     qmlRegisterType<MonthModel>("org.kde.kalendar", 1, 0, "MonthModel");
     qmlRegisterType<InfiniteCalendarViewModel>("org.kde.kalendar", 1, 0, "InfiniteCalendarViewModel");
 
+    qRegisterMetaType<Akonadi::ETMCalendar::Ptr>();
     qRegisterMetaType<Akonadi::AgentFilterProxyModel *>();
     qRegisterMetaType<QAction *>();
 
