@@ -1,19 +1,15 @@
 // SPDX-FileCopyrightText: 2021 Claudio Cambra <claudio.cambra@gmail.com>
 // SPDX-License-Identifier: LGPL-2.1-or-later
+
+#include "tagmanager.h"
 #include "kalendar_debug.h"
+
 #include <QObject>
 #include <akonadi_version.h>
-#if AKONADI_VERSION >= QT_VERSION_CHECK(5, 18, 41)
 #include <Akonadi/TagCreateJob>
 #include <Akonadi/TagDeleteJob>
 #include <Akonadi/TagModifyJob>
-#else
-#include <AkonadiCore/TagCreateJob>
-#include <AkonadiCore/TagDeleteJob>
-#include <AkonadiCore/TagModifyJob>
-#endif
 #include <KDescendantsProxyModel>
-#include <tagmanager.h>
 
 class FlatTagModel : public QSortFilterProxyModel
 {
