@@ -2,15 +2,11 @@
 // SPDX-License-Identifier: LGPL-2.1-or-later
 
 #pragma once
+
 #include <QObject>
 #include <akonadi_version.h>
-#if AKONADI_VERSION >= QT_VERSION_CHECK(5, 18, 41)
 #include <Akonadi/Monitor>
 #include <Akonadi/TagModel>
-#else
-#include <AkonadiCore/Monitor>
-#include <AkonadiCore/TagModel>
-#endif
 #include <QSortFilterProxyModel>
 
 class TagManager : public QObject
